# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ProjectArgs', 'Project']

@pulumi.input_type
class ProjectArgs:
    def __init__(__self__, *,
                 order_type: pulumi.Input[str],
                 specification_type: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Project resource.
        :param pulumi.Input[str] order_type: The type of payment, only `PayAsYouGo` supported currently.
        :param pulumi.Input[str] specification_type: The type of resource Specification, only `OdpsStandard` supported currently.
        :param pulumi.Input[str] name: It has been deprecated from provider version 1.110.0 and `project_name` instead.
        :param pulumi.Input[str] project_name: The name of the maxcompute project.
        """
        pulumi.set(__self__, "order_type", order_type)
        pulumi.set(__self__, "specification_type", specification_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="orderType")
    def order_type(self) -> pulumi.Input[str]:
        """
        The type of payment, only `PayAsYouGo` supported currently.
        """
        return pulumi.get(self, "order_type")

    @order_type.setter
    def order_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "order_type", value)

    @property
    @pulumi.getter(name="specificationType")
    def specification_type(self) -> pulumi.Input[str]:
        """
        The type of resource Specification, only `OdpsStandard` supported currently.
        """
        return pulumi.get(self, "specification_type")

    @specification_type.setter
    def specification_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "specification_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        It has been deprecated from provider version 1.110.0 and `project_name` instead.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the maxcompute project.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)


@pulumi.input_type
class _ProjectState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 order_type: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 specification_type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Project resources.
        :param pulumi.Input[str] name: It has been deprecated from provider version 1.110.0 and `project_name` instead.
        :param pulumi.Input[str] order_type: The type of payment, only `PayAsYouGo` supported currently.
        :param pulumi.Input[str] project_name: The name of the maxcompute project.
        :param pulumi.Input[str] specification_type: The type of resource Specification, only `OdpsStandard` supported currently.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if order_type is not None:
            pulumi.set(__self__, "order_type", order_type)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if specification_type is not None:
            pulumi.set(__self__, "specification_type", specification_type)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        It has been deprecated from provider version 1.110.0 and `project_name` instead.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orderType")
    def order_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of payment, only `PayAsYouGo` supported currently.
        """
        return pulumi.get(self, "order_type")

    @order_type.setter
    def order_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "order_type", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the maxcompute project.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="specificationType")
    def specification_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of resource Specification, only `OdpsStandard` supported currently.
        """
        return pulumi.get(self, "specification_type")

    @specification_type.setter
    def specification_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "specification_type", value)


class Project(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 order_type: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 specification_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The project is the basic unit of operation in maxcompute. It is similar to the concept of Database or Schema in traditional databases, and sets the boundary for maxcompute multi-user isolation and access control. [Refer to details](https://www.alibabacloud.com/help/doc-detail/27818.html).

        ->**NOTE:** Available in 1.77.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.maxcompute.Project("example",
            order_type="PayAsYouGo",
            project_name="tf_maxcompute_project",
            specification_type="OdpsStandard")
        ```

        ## Import

        MaxCompute project can be imported using the *name* or ID, e.g.

        ```sh
         $ pulumi import alicloud:maxcompute/project:Project example tf_maxcompute_project
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: It has been deprecated from provider version 1.110.0 and `project_name` instead.
        :param pulumi.Input[str] order_type: The type of payment, only `PayAsYouGo` supported currently.
        :param pulumi.Input[str] project_name: The name of the maxcompute project.
        :param pulumi.Input[str] specification_type: The type of resource Specification, only `OdpsStandard` supported currently.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The project is the basic unit of operation in maxcompute. It is similar to the concept of Database or Schema in traditional databases, and sets the boundary for maxcompute multi-user isolation and access control. [Refer to details](https://www.alibabacloud.com/help/doc-detail/27818.html).

        ->**NOTE:** Available in 1.77.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.maxcompute.Project("example",
            order_type="PayAsYouGo",
            project_name="tf_maxcompute_project",
            specification_type="OdpsStandard")
        ```

        ## Import

        MaxCompute project can be imported using the *name* or ID, e.g.

        ```sh
         $ pulumi import alicloud:maxcompute/project:Project example tf_maxcompute_project
        ```

        :param str resource_name: The name of the resource.
        :param ProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 order_type: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 specification_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectArgs.__new__(ProjectArgs)

            __props__.__dict__["name"] = name
            if order_type is None and not opts.urn:
                raise TypeError("Missing required property 'order_type'")
            __props__.__dict__["order_type"] = order_type
            __props__.__dict__["project_name"] = project_name
            if specification_type is None and not opts.urn:
                raise TypeError("Missing required property 'specification_type'")
            __props__.__dict__["specification_type"] = specification_type
        super(Project, __self__).__init__(
            'alicloud:maxcompute/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None,
            order_type: Optional[pulumi.Input[str]] = None,
            project_name: Optional[pulumi.Input[str]] = None,
            specification_type: Optional[pulumi.Input[str]] = None) -> 'Project':
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: It has been deprecated from provider version 1.110.0 and `project_name` instead.
        :param pulumi.Input[str] order_type: The type of payment, only `PayAsYouGo` supported currently.
        :param pulumi.Input[str] project_name: The name of the maxcompute project.
        :param pulumi.Input[str] specification_type: The type of resource Specification, only `OdpsStandard` supported currently.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectState.__new__(_ProjectState)

        __props__.__dict__["name"] = name
        __props__.__dict__["order_type"] = order_type
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["specification_type"] = specification_type
        return Project(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        It has been deprecated from provider version 1.110.0 and `project_name` instead.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orderType")
    def order_type(self) -> pulumi.Output[str]:
        """
        The type of payment, only `PayAsYouGo` supported currently.
        """
        return pulumi.get(self, "order_type")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[str]:
        """
        The name of the maxcompute project.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="specificationType")
    def specification_type(self) -> pulumi.Output[str]:
        """
        The type of resource Specification, only `OdpsStandard` supported currently.
        """
        return pulumi.get(self, "specification_type")

